otcextensions.sdk.modelartsv1.v1.training_job_version
=====================================================

.. automodule:: otcextensions.sdk.modelartsv1.v1.training_job_version

The ModelArts TrainingJobVersion Class
--------------------------------------

The ``Config`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.modelartsv1.v1.training_job_version.TrainingJobVersion
   :members:
